@@ -32,13 +32,8 @@
 #include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-string.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtktextbuffer.h>
-#include <gtk/gtktextview.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <libgnome/gnome-i18n.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-file.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
@@ -47,6 +42,8 @@
 #include <libnautilus-private/nautilus-clipboard.h>
 #include <libnautilus-private/nautilus-module.h>
 #include <libnautilus-private/nautilus-sidebar-provider.h>
+#include <libnautilus-private/nautilus-window-info.h>
+#include <libnautilus-private/nautilus-window-slot-info.h>
 #include <libnautilus-extension/nautilus-property-page-provider.h>
 
 #define SAVE_TIMEOUT (3 * 1000)
@@ -247,7 +244,7 @@ notes_load_metainfo (NautilusNotesViewer *notes)
         NautilusFileAttributes attributes;
         
         done_with_file (notes);
-        notes->details->file = nautilus_file_get (notes->details->uri);
+        notes->details->file = nautilus_file_get_by_uri (notes->details->uri);
 
         /* Block the handler, so we don't respond to our own change.
          */
@@ -279,7 +276,7 @@ notes_load_metainfo (NautilusNotesViewer *notes)
 }
 
 static void
-loading_uri_callback (NautilusSidebar *sidebar,
+loading_uri_callback (NautilusWindowInfo *window,
                       const char *location,
                       NautilusNotesViewer *notes)
 {
@@ -312,19 +309,16 @@ on_changed (GtkEditable *editable, NautilusNotesViewer *notes)
 static void
 nautilus_notes_viewer_init (NautilusNotesViewer *sidebar)
 {
-        char *image_path;
         NautilusNotesViewerDetails *details;
+	NautilusIconInfo *info;
         
         details = g_new0 (NautilusNotesViewerDetails, 1);
         sidebar->details = details;
         
         details->uri = g_strdup ("");
 
-        image_path = nautilus_pixmap_file ("note-indicator.png");
-        if (image_path) {
-                details->icon = gdk_pixbuf_new_from_file (image_path, NULL);
-                g_free (image_path);
-        }
+	info = nautilus_icon_info_lookup_from_name ("emblem-note", 16);
+	details->icon = nautilus_icon_info_get_pixbuf (info);
 
         /* create the text container */               
 	details->text_buffer = gtk_text_buffer_new (NULL);
@@ -430,11 +424,15 @@ static void
 nautilus_notes_viewer_set_parent_window (NautilusNotesViewer *sidebar,
                                           NautilusWindowInfo *window)
 {
+	NautilusWindowSlotInfo *slot;
+
+	slot = nautilus_window_info_get_active_slot (window);
+
 	g_signal_connect_object (window, "loading_uri",
 				 G_CALLBACK (loading_uri_callback), sidebar, 0);
         
         g_free (sidebar->details->uri);
-        sidebar->details->uri = nautilus_window_info_get_current_location (window);
+	sidebar->details->uri = nautilus_window_slot_info_get_current_location (slot);
         notes_load_metainfo (sidebar);
 
 	nautilus_clipboard_set_up_text_view
